#------------------------------------------------------------------------------
#
#                                  SLIP.CFG
#
#                          SLIP Configuration File
#             ..................................................
#
#                             Copyright (c) 1993
#               David Bolen and Advanced Network & Services, Inc.
#                            All Rights Reserved
#
# This file controls the interfaces that the SLIP driver creates and manages.
# It is used to set up interface values (such as MTU, RTT estimates, and
# device information), as well as specifying other per-interface data, such
# as what scripts should be run to make a SLIP attachment over an interface.
#
# The general format of the file is a series of interface "clauses", of the
# form:
#
#               interface ??? {         # Comments
#                    parameter = value  [,] [ parameter = value [,] ... ]
#               }
#
# Spaces, commas and newlines are ignored (except within quoted strings).
# In general, the layout of the file is free-form, within the general bounds
# of the interface blocks.
#
# Comments may begin at any point on the line, and are signified by a hash
# (#) character - everything past the comment character is ignored.
#
# Parameter names and values are delimited by whitespace.  Special characters
# (whitespace, ',', '{', '}', '#', '=') may be included in a value by
# surrounding that value in double quotes ("), or by prefixing the special
# character with a backslash (\).  Use \\ to get a backslash itself, and use
# \" within a quoted string to get a double quote within the value.
#
# In the above, ??? specifies an interface to be defined.  Currently only
# two values are allowed:
#
#       default         Default settings.  Specifies parameters that will
#                       be assumed for any interfaces later in the file
#                       where their interface clauses do not contain new
#                       values for the parameters.
#       sl0             Serial Interface 0.
#
# The "interface default" clause may be specified multiple times, and is
# additive.  Where a parameter appears in more than one such clause, its
# most recent value will be used for any later interface clauses.
#
# The following parameters and values are allowed for each interface:
#
#   Basic Parameters
#       device          Interface serial device (ie: "com1")
#       mtu             Maximum transmission unit (bytes)
#       compression     Adjusts VJ compression.  Can be "ON" (always compress),
#                         "OFF" (never), or "AUTO" (accept compression and
#                         start compressing if compressed packets are received)
#       attachcmd       Name of rexx command script to run to attach interface
#       attachparms       Parameters to pass to command script
#
#   Queuing Parameters
#       fastqueue       Enables priority queueing for interactive traffic.
#       nofastqueue       Disables priority queueing
#       queuesize       Normal and priority queue sizes (IP kernel<->SLIP) in
#       fastqueuesize     packets.  These should be multiples of 4.
#
#   Protocol Parameters
#       rtt             Initial TCP RTT estimates.  Like BSD-Reno's per-route
#       rttvar            defaults, but per-interface.  The values assigned
#       rttmin            to these parameters are in milliseconds
#       sendpipe        Size of TCP send and receive windows (bytes)
#       recvpipe
#       ssthresh        "Slow start" congestion window threshold (bytes)
#
# When this file is initially processed, the system default interface clause
# is as follows:
#
#       interface default {
#          mtu=296, compression=on,
#          fastqueue, queuesize=12, fastqueuesize=24,
#          recvpipe=4096
#       }
#
# And the default device for the "sl0" interface is "com1"
#
# It is not recommended that anything other than "Basic Parameter" values
# be adjusted unless truly necessary.  In particular, adjusting queue sizes
# and rtt* values without a complete understanding of the effect such
# adjustments will have on protocol (such as TCP) behavior can seriously
# affect both interactive response and throughput.
#
# The "attachparms" must contain in this order: the userid, the password,
# and the dial command(s). If any of these is specified as an asterisk (*),
# the script will prompt you for that value. You can specify several dial
# commands, each will be tried in turn until a connection is established.
#
#------------------------------------------------------------------------------
# Set up a simple default sl0 (default parameter values commented above)
#
interface sl0 {
 device=COM1,
 mtu=1006,
 compression=on,
 attachcmd=xs4all,
 attachparms="userid password atdt020-6222175 atdt020-6265060"
}
